local country "es lu" 

loc c "es" 

	clear
	use ${mydata}/extract-`c' , clear
	svyset [pw=ppopwgt] , psu(hid) strata(year) 
	
	tab tersex period [aw=ppopwgt] , col

	svy , subpop(if period==0) : mean capearn , over(tersex)  
	svy , subpop(if period==1) : mean capearn , over(tersex)  
	
	// Inequality decomposition by group
	ineqdeco capearn if period==0 [aw=ppopwgt], by(tersex)    
	ineqdeco capearn if period==1 [aw=ppopwgt], by(tersex)    

	// Morduch-Sicular
	ineqrbd capearn fnonter mter fter  if period==0  [aw=ppopwgt]
	ineqrbd capearn fnonter mter fter  if period==1  [aw=ppopwgt]

	// Inequality decomposition by group -- counterfactuals
	ineqdeco capearn if period==0 [aw=ppopwgt], by(tersex) 
	di r(between_ge0) + r(v_1)*r(ge0_1) + r(v_2)*r(ge0_2) + r(v_12)*r(ge0_12) + r(v_11)*r(ge0_11) 
	foreach i in 1 2 11 12 {
		local ge0_`i'_0    r(ge0_`i') 
	}
	ineqdeco capearn if period==1 [aw=ppopwgt], by(tersex)    
	 di r(between_ge0) + r(v_1)*r(ge0_1) + r(v_2)*r(ge0_2) + r(v_12)*r(ge0_12) + r(v_11)*r(ge0_11) 
	 di "What if within group inequality had not changed?"
	 di r(between_ge0) + r(v_1)*`ge0_1_0' + r(v_2)*`ge0_2_0' + r(v_12)*`ge0_12_0' + r(v_11)*`ge0_11_0' 

	// Bootstrap inference? Simplest form
	cap pr drop bootineq
	pr def bootineq , rclass
		// calculation
		ineqdeco capearn if period==0 [aw=ppopwgt], by(tersex) 
		loc ge0_0   = r(ge0) 
		foreach i in 1 2 11 12 {
			local ge0_`i'_0  =   r(ge0_`i') 
		}
		ineqdeco capearn if period==1 [aw=ppopwgt], by(tersex)   
		loc ge0_1   = r(ge0) 
		loc ge0_01  = r(between_ge0) + r(v_1)*`ge0_1_0' + r(v_2)*`ge0_2_0' + r(v_12)*`ge0_12_0' + r(v_11)*`ge0_11_0' 
		// return results
		return scalar ge0_0 = `ge0_0'
		return scalar ge0_1 = `ge0_1'
		return scalar ge0_01= `ge0_01'
		return scalar diff = `ge0_1' - `ge0_0'
		return scalar exdiff = `ge0_01' - `ge0_0'
	end
	bootstrap  	ge0_0 = r(ge0_0)  ///
				ge0_1 = r(ge0_1) 	///
				ge0_01 = r(ge0_01) ///
				diff = r(diff) ///
				exdiff=r(exdiff) ///
				, reps(50) strata(year) cluster(hid) ///
				: 	bootineq 
		
	// Kdensities
	qui su capearn , detail
	range xgrid `=r(p1)/2' `=r(p99)*1.1' 199
	kdens capearn if period==0 & tersex==1 [aw=ppopwgt] , at(xgrid) gen(f01) 
	kdens capearn if period==0 & tersex==2 [aw=ppopwgt] , at(xgrid) gen(f02) 
	kdens capearn if period==0 & tersex==11 [aw=ppopwgt] , at(xgrid) gen(f011) 
	kdens capearn if period==0 & tersex==12 [aw=ppopwgt] , at(xgrid) gen(f012)
	svy , subpop(if period==0) :  proportion tersex 
	gen f0 = 0
	foreach i in 1 2 11 12 {
		gen scf0`i' = _b[`i'.tersex] * f0`i'
		replace f0 = f0 + scf0`i'	
	}
	
	kdens capearn if period==1 & tersex==1 [aw=ppopwgt] , at(xgrid) gen(f11) 
	kdens capearn if period==1 & tersex==2 [aw=ppopwgt] , at(xgrid) gen(f12) 
	kdens capearn if period==1 & tersex==11 [aw=ppopwgt] , at(xgrid) gen(f111) 
	kdens capearn if period==1 & tersex==12 [aw=ppopwgt] , at(xgrid) gen(f112)
	svy , subpop(if period==1) :  proportion tersex 
	gen f1 = 0
	foreach i in 1 2 11 12 {
		gen scf1`i' = _b[`i'.tersex] * f1`i'
		replace f1 = f1 + scf1`i'	
	}
	// counterfactual
	gen f10 = 0
	foreach i in 1 2 11 12 {
		gen scf10`i' = _b[`i'.tersex] * f0`i'
		replace f10 = f10 + scf10`i'	
	}

	
	// check to display on same scale:
	qui su f0  , meanonly
	loc max = r(max)
	qui su f1  , meanonly
	loc max = max(`max',r(max))
	qui su f10  , meanonly
	loc max = max(`max',r(max))
	
	tw line f0 scf01 scf02 scf011 scf012 xgrid , yscale(range(0 `max'))
	graphexportpdf $mypdf/kdens0 
	tw line f1 scf11 scf12 scf111 scf112 xgrid , yscale(range(0 `max'))
	graphexportpdf $mypdf/kdens1
	tw line f0 f1 f10  xgrid , yscale(range(0 `max'))
	graphexportpdf $mypdf/kdens10

	// log scale gives better sense of relative inequality
	tw line f0 scf01 scf02 scf011 scf012 xgrid , yscale(range(0 `max')) xscale(log) 
	graphexportpdf $mypdf/kdens0_log 
	tw line f1 scf11 scf12 scf111 scf112 xgrid , yscale(range(0 `max')) xscale(log) 
	graphexportpdf $mypdf/kdens1_log
	tw line f0 f1 f10  xgrid , yscale(range(0 `max')) xscale(log) 
	graphexportpdf $mypdf/kdens10_log
	
	*}

exit
	

	