local country "es lu" 
loc c "es" 

	clear
	use ${mydata}/extract-`c' , clear
	svyset [pw=ppopwgt] , psu(hid) strata(year) 
	tab inda1 , gen(dinda1)   // generate dummy variables
	loc covariates  	c.age##c.age i.ptime1 i.inda1 
	loc covariatesnoi  	age age2 ptime1 dinda12 dinda13 
	
	// reweighting approach
	
	svy : logit period  i.tersex   
	predict p1   // probability to "be in period 1" given sex educ
	svy : logit period  i.tersex i.tersex#(`covariates')  
	predict p2   // probability to "be in perdio 1 given sex educ and other cov"

	gen rw1 = cond(period==1 , 1 , p1/(1-p1))
	gen rw2 = cond(period==1 , 1 , p2/(1-p2))

	tab tersex period [aw=ppopwgt] , col
	tab tersex period [aw=ppopwgt*rw1]  , col
	tab tersex period [aw=ppopwgt*rw2]  , col
	
	tab inda1 period [aw=ppopwgt] , col
	tab inda1 period [aw=ppopwgt*rw1]  , col
	tab inda1 period [aw=ppopwgt*rw2]  , col
	tab inda1 period if tersex==1 [aw=ppopwgt*rw2]  , col

	* Period 0 inequality
	sgini capearn if period==0 [aw=ppopwgt] 
	* Period 0 inequality if gender and education of period 1 (what is held fixed is within group inequality)
	sgini capearn if period==0  [aw=ppopwgt*rw1]
	* Period 0 inequality if gender and education and industry and age etc. of period 1 (what is held fixed is within group inequality)
	sgini capearn if period==0  [aw=ppopwgt*rw2]
	* Period 1 inequalty  
	sgini capearn if period==1  [aw=ppopwgt] 
		
	// distribution regression -- illustration using quantile regression
	// use the -counterfactual- command:
	counterfactual capearn fnonter fter mter `covariatesnoi' [aw=ppopwgt] , group(period) noboot method(lpm)
	
	// quantile regression:
	preserve
	foreach quant of numlist 1(2)99 {
		quietly qreg lncapearn `covariates' [pw=ppopwgt] if period==0 , quantile(`quant')
		qui predict lnq_0_`quant'    // predict for both period 0 and 1 !
		qui gen q_0_`quant' = exp(lnq_0_`quant')

		quietly qreg lncapearn `covariates' [pw=ppopwgt] if period==1 , quantile(`quant')
		qui predict lnq_1_`quant'
		qui gen q_1_`quant' = exp(lnq_1_`quant')	
	}
	
	keep upid q* period ppopwgt 
	reshape long q_0_ q_1_ , i(upid period) j(quant)
	reshape error 
	sample 50
	sgini q_0_ if period==0  [aw=ppopwgt] 
	sgini q_0_ if period==1  [aw=ppopwgt] 
	sgini q_1_ if period==0  [aw=ppopwgt] 
	sgini q_1_ if period==1  [aw=ppopwgt] 
	restore

	// Singh-Maddala model:
	preserve

	smfit capearn [aw=ppopwgt] if period==0 ,  a(fnonter fter mter)  b(`covariatesnoi')   itera(50)
	predict double a0, eq(a) xb
    predict double b0, eq(b) xb
    predict double q0, eq(q) xb
	smfit capearn [aw=ppopwgt] if period==1 ,  a(fnonter fter mter )  b(`covariatesnoi')   itera(50)
	predict double a1, eq(a) xb
    predict double b1, eq(b) xb
    predict double q1, eq(q) xb
	foreach quant of numlist 2(2)98 {
		loc p = `quant' / 100
		qui gen q_0_`quant' = b0*((1-`p')^(-1/q0) - 1)^(1/a0)
		qui gen q_1_`quant' = b1*((1-`p')^(-1/q1) - 1)^(1/a1)
	}	
	keep upid q* period ppopwgt 
	reshape long q_0_ q_1_ , i(upid period) j(quant)
	sample 50
	sgini q_0_ if period==0  [aw=ppopwgt] 
	sgini q_0_ if period==1  [aw=ppopwgt] 
	sgini q_1_ if period==0  [aw=ppopwgt] 
	sgini q_1_ if period==1  [aw=ppopwgt] 
	restore
	
	
	

	